@@ -8,9 +8,13 @@
 #'  selected.
 #'@param prevar A vector containing the number of the best subset of
 #'  \code{q-1} variables. \code{NULL}, by default.
-#'@param criterion The cross-validation-based information criterion to be used.
-#'  Default is the deviance. Other functions provided are the coefficient of
-#'  determination (\code{"R2"}) and residual variance (\code{"variance"}).
+#'@param criterion The information criterion to be used.
+#'  Default is the deviance. Other functions provided
+#'  are the coefficient of determination (\code{"R2"}), the residual
+#'  variance (\code{"variance"}), the Akaike information criterion (\code{"aic"}),
+#'  AIC with a correction for finite sample sizes (\code{"aicc"})
+#'  and the Bayesian information criterion (\code{"bic"}). The deviance,
+#'  coefficient of determination and variance are calculated by cross-validation.
 #'@param method A character string specifying which regression method is used,
 #'  i.e., linear models (\code{"lm"}), generalized additive models
 #'  (\code{"glm"}) or generalized additive models (\code{"gam"}).
@@ -21,7 +25,8 @@
 #'  then, rather than returning the single best model only, the function returns
 #'  a few of the best models (equivalent).
 #'@param nmodels Number of secondary models to be returned.
-#'@param nfolds Number of folds for the cross-validation procedure.
+#'@param nfolds Number of folds for the cross-validation procedure, for
+#'\code{deviance}, \code{R2} or \code{variance} criterion.
 #'@param cluster A logical value. If  \code{TRUE} (default), the
 #'  procedure is  parallelized. Note that there are cases without enough
 #'  repetitions (e.g., a low number of initial variables) that R will gain in
@@ -74,6 +79,9 @@
 #'@importFrom stats predict
 #'@importFrom stats update
 #'@importFrom stats var
+#'@importFrom stats AIC
+#'@importFrom stats BIC
+#'@importFrom stats logLik
 #'@export
 
 
@@ -103,8 +111,14 @@ selection <- function(x, y, q, prevar = NULL, criterion = "deviance",
   }
 
 
+  if(!criterion %in% c("deviance", "R2", "variance", "aic", "aicc", "bic")) {
+    stop('The selected criterion is not implemented')
+  }
+
+
   if (cluster == TRUE & detectCores() == 2 & is.null(ncores)) {
-    stop("The number of cores used in the parallelized procedure is just one. It is recommended to use cluster = FALSE ")
+    stop("The number of cores used in the parallelized procedure is just one.
+         It is recommended to use cluster = FALSE ")
   }
 
   # for paralellize
@@ -146,7 +160,8 @@ selection <- function(x, y, q, prevar = NULL, criterion = "deviance",
       xyes[l] = xnam
     }
 
-    form1 <- update(as.formula(model, env = environment(fun = NULL)), paste(". ~ ", paste(xyes, collapse = "+")))
+    form1 <- update(as.formula(model, env = environment(fun = NULL)), paste(". ~ ",
+                                                                            paste(xyes, collapse = "+")))
     if (method == "gam"){
       model <- gam(form1, family = family)
     }else{
@@ -237,7 +252,8 @@ selection <- function(x, y, q, prevar = NULL, criterion = "deviance",
     }
 
     xyes[k] = xnam
-    form1 <- update(as.formula(model, env = environment(fun = NULL)), paste(". ~ ", paste(xyes, collapse = "+")))
+    form1 <- update(as.formula(model, env = environment(fun = NULL)), paste(". ~ ",
+                                                                            paste(xyes, collapse = "+")))
     if (method == "gam"){
       model <- gam(form1, family = family)
     }else{
@@ -395,7 +411,23 @@ selection <- function(x, y, q, prevar = NULL, criterion = "deviance",
     return(mean(unlist(cv_ics)))
   }
 
-  icfin <- cv(nfolds)
+  aicc <- function(model){
+    n <- length(model$y)
+    k <- attr(logLik(model), "df")
+    res <- AIC(model) + 2 * k * (k+1)/(n-k-1)
+  }
+
+  if(criterion %in% c("deviance", "R2", "variance")){
+    icfin <- cv(nfolds)
+  }else{
+    if (criterion == "aic"){
+     icfin <- AIC(model)
+    }else if(criterion == "aicc"){
+      icfin <- aicc(model)
+    }else{
+      icfin <- BIC(model)
+    }
+  }
 
   if(class(x) == "data.frame"){
     names1 = names(x[inside])
@@ -504,7 +536,17 @@ selection <- function(x, y, q, prevar = NULL, criterion = "deviance",
       besticn = deviance(model)
 
 
-      icfin <- cv(nfolds)
+      if(criterion %in% c("deviance", "R2", "variance")){
+        icfin <- cv(nfolds)
+      }else{
+        if (criterion == "aic"){
+          icfin <- AIC(model)
+        }else if(criterion == "aicc"){
+          icfin <- aicc(model)
+        }else{
+          icfin <- BIC(model)
+        }
+      }
 
       if(class(x) == "data.frame"){
         names2 = names(x[inside])
